import arcpy, os
arcpy.env.overwriteOutput = True

#Get input parameters and set constants
Output_GDB = arcpy.GetParameter(0)
FeatureClass_Marks = arcpy.GetParameter(1)
FeatureClass_ParcelTypeBoundaries = arcpy.GetParameter(2)
FeatureClass_Parcels_C = arcpy.GetParameter(3)
FeatureClass_Parcels_E = arcpy.GetParameter(4)
Table_CS = arcpy.GetParameter(5)
Table_EP = arcpy.GetParameter(6)
Table_PA = arcpy.GetParameter(7)
Geographic_Transformation = "S-JTSK_[JTSK03]_To_S-JTSK_1 + S-JTSK_[JTSK03]_To_WGS_1984_1"
Output_Coordinate_System = arcpy.SpatialReference(3857)

#Chain all layers into list
FeatureClassList = []
if arcpy.Exists(FeatureClass_Marks):
    FeatureClassList.append(FeatureClass_Marks)
if arcpy.Exists(FeatureClass_ParcelTypeBoundaries):
    FeatureClassList.append(FeatureClass_ParcelTypeBoundaries)
if arcpy.Exists(FeatureClass_Parcels_C):
    FeatureClassList.append(FeatureClass_Parcels_C)
if arcpy.Exists(FeatureClass_Parcels_E):
    FeatureClassList.append(FeatureClass_Parcels_E)

arcpy.AddMessage(len(FeatureClassList))

#Main part

for FeatureClass in FeatureClassList:
    FeatureClass_Name = str(FeatureClass).rsplit("\\",1)[-1]
    FeatureClass_DescribeObject = arcpy.Describe(FeatureClass)
    FeatureClass_SpatialReference = FeatureClass_DescribeObject.spatialReference
    Input_Coordinate_System = FeatureClass_SpatialReference

    if Input_Coordinate_System.PCSCode not in [5514,8353]:
        arcpy.AddMessage("Vrstva" + FeatureClass.name + "nema suradnicovy system JTSK alebo JTSK03")
    else:
        Output_FeatureClass = arcpy.management.Project(in_dataset=FeatureClass, out_dataset=str(Output_GDB) + "\\" + FeatureClass_Name, out_coor_system=Output_Coordinate_System, transform_method=Geographic_Transformation, in_coor_system=Input_Coordinate_System)

        #Process specifically Parcels_C
        if FeatureClass_Name == "kladpar_plochy":
            arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="CPA_NUM", field_type="LONG")
            arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="CPA_NUM", expression="!CPA!.replace('.','') + '0'", expression_type="PYTHON3")
            arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="CPA_TEXT", field_type="TEXT", field_length=15)
            arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="CPA_TEXT", expression="Spracuj(!CPA!)", expression_type="PYTHON3", code_block="""
def Spracuj(CPA):
    if (CPA.rfind('.000') > 0 ):
        return CPA.replace('.000','')
    elif (CPA.rfind('.00') > 0 ):
        return CPA.replace('.00','/')
    elif (CPA.rfind('.0') > 0 ):
        return CPA.replace('.0','/')
    else:
        return CPA.replace('.','/')
""")
            if arcpy.Exists(Table_CS):
                arcpy.management.JoinField(in_data=Output_FeatureClass[0], in_field="CPA_NUM", join_table=Table_CS, join_field="CPA", fields=["PEC", "DRS"])
                if str(Output_GDB) == os.getcwd() + "\\Vysledok.gdb":
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "DRS", "DRS" )
                    
            if arcpy.Exists(Table_PA):
                arcpy.management.JoinField(in_data=Output_FeatureClass[0], in_field="CPA_NUM", join_table=Table_PA, join_field="CPA", fields=["CLV", "DRP", "PKK", "UMP", "VYM"])
                arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="LV_online", field_type="TEXT", field_length=1000, field_alias="List vlastníctva (online)")
                arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="LV_pdf",    field_type="TEXT", field_length=1000, field_alias="List vlastníctva (PDF)")
                Output_FeatureClass = arcpy.management.SelectLayerByAttribute(in_layer_or_view=Output_FeatureClass[0], selection_type="NEW_SELECTION", where_clause="CLV > 0")
                arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="LV_online", expression="\"<a href='\" + \"https://kataster.skgeodesy.sk/Portal/api/Bo/GeneratePrfPublic?prfNumber=\" + $feature.CLV + \"&cadastralUnitCode=\" + $feature.CKU + \"&outputType=html\" + \"' target='_top'>Kliknite sem</a>\" ", expression_type="ARCADE")
                arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="LV_pdf",    expression="\"<a href='\" + \"https://kataster.skgeodesy.sk/Portal/api/Bo/GeneratePrfPublic?prfNumber=\" + $feature.CLV + \"&cadastralUnitCode=\" + $feature.CKU + \"&outputType=pdf\" + \"' target='_top'>Kliknite sem</a>\" ", expression_type="ARCADE")
                if str(Output_GDB) == os.getcwd() + "\\Vysledok.gdb":
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "DRP", "DRP" )
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "PKK", "PKK" )
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "UMP", "UMP" )
                
        #Process specifically Parcels_E
        if FeatureClass_Name == "uov_plochy":
            arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="CPA_NUM", field_type="LONG")
            arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="CPA_NUM", expression="""
                IIf(
                    Find(\"-\",$feature.CPA) > -1,
                        Split(Replace($feature.CPA,\".\",\"\")+\"0\",\"-\",-1)[1],
                        Replace($feature.CPA,\".\",\"\")+\"0\"
                )""", expression_type="ARCADE")
            arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="CPA_TEXT", field_type="TEXT", field_length=15)
            arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="CPA_TEXT", expression="Spracuj(!CPA!)", expression_type="PYTHON3", code_block="""
def Spracuj(CPA):
    if (CPA.rfind('.000') > 0 ):
        return CPA.replace('.000','')
    elif (CPA.rfind('.00') > 0 ):
        return CPA.replace('.00','/')
    elif (CPA.rfind('.0') > 0 ):
        return CPA.replace('.0','/')
    else:
        return CPA.replace('.','/')
""")
            if arcpy.Exists(Table_EP):
                arcpy.management.JoinField(in_data=Output_FeatureClass[0], in_field="CPA_NUM", join_table=Table_EP, join_field="CPA", fields=["CLV", "DRP", "PKK", "UMP", "VYM"])
                Output_FeatureClass = arcpy.management.SelectLayerByAttribute(in_layer_or_view=Output_FeatureClass[0], selection_type="NEW_SELECTION", where_clause="CPA_TEXT = '0'")
                arcpy.management.DeleteFeatures(in_features=Output_FeatureClass[0])
                arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="LV_online", field_type="TEXT", field_length=1000, field_alias="List vlastníctva (online)")
                arcpy.management.AddField(in_table=Output_FeatureClass[0], field_name="LV_pdf",    field_type="TEXT", field_length=1000, field_alias="List vlastníctva (PDF)")
                Output_FeatureClass = arcpy.management.SelectLayerByAttribute(in_layer_or_view=Output_FeatureClass[0], selection_type="NEW_SELECTION", where_clause="CLV > 0")
                arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="LV_online", expression="\"<a href='\" + \"https://kataster.skgeodesy.sk/Portal/api/Bo/GeneratePrfPublic?prfNumber=\" + $feature.CLV + \"&cadastralUnitCode=\" + $feature.CKU + \"&outputType=html\" + \"' target='_top'>Kliknite sem</a>\" ", expression_type="ARCADE")
                arcpy.management.CalculateField(in_table=Output_FeatureClass[0], field="LV_pdf",    expression="\"<a href='\" + \"https://kataster.skgeodesy.sk/Portal/api/Bo/GeneratePrfPublic?prfNumber=\" + $feature.CLV + \"&cadastralUnitCode=\" + $feature.CKU + \"&outputType=pdf\" + \"' target='_top'>Kliknite sem</a>\" ", expression_type="ARCADE")
                if str(Output_GDB) == os.getcwd() + "\\Vysledok.gdb":
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "DRP", "DRP" )
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "PKK", "PKK" )
                    arcpy.AssignDomainToField_management(Output_FeatureClass[0], "UMP", "UMP" )
